complete -c create_ap -f
complete -c create_ap -a '(__fish_print_interfaces)'
complete -c create_ap -s h -l help -d 'Show help'
complete -c create_ap -l version -d 'Print version number'
complete -c create_ap -s c -x -d 'Channel number'
complete -c create_ap -s w -x -a '1 2 1+2' -d 'WPA version to use'
complete -c create_ap -s n -d 'Disable Internet sharing'
complete -c create_ap -s m -x -a 'nat brigde none' -d 'Method for Internet sharing'
complete -c create_ap -l psk -d 'Use 64 hex digits pre-shared-key'
complete -c create_ap -l hidden -d 'Make the Access Point hidden'
complete -c create_ap -l mac-filter -d 'Enable MAC address filtering'
complete -c create_ap -l mac-filter-accept -d 'Location of MAC address filter list'
complete -c create_ap -l redirect-to-localhost -d 'Redirect every web request to localhost'
complete -c create_ap -l hostapd-debug -x -d 'Hostapd debug level'
complete -c create_ap -l isolate-clients -d 'Disable communication between clients'
complete -c create_ap -l ieee80211n -d 'Enable IEEE 802.11n'
complete -c create_ap -l ieee80211ac -d 'Enable IEEE 802.11ac'
complete -c create_ap -l ht_capab -x -d 'HT capabilities'
complete -c create_ap -l vht_capab -x -d 'VHT capabilities'
complete -c create_ap -l country -x -d 'Set two-letter country code'
complete -c create_ap -l freq-band -x -a '2.4 5' -d 'Set frequency band'
complete -c create_ap -l driver -d 'Choose your WiFi adapter driver'
complete -c create_ap -l no-virt -d 'Do not create virtual interface'
complete -c create_ap -l no-haveged -d 'Do not run \'haveged\' automatically when needed'
complete -c create_ap -l fix-unmanaged -d 'Fix NetworkManager showing interface as unmanaged'
complete -c create_ap -l mac -x -d 'Set MAC address'
complete -c create_ap -l dhcp-dns -x -d 'Set DNS returned by DHCP'
complete -c create_ap -l daemon -d 'Run create_ap in the background'
complete -c create_ap -l pidfile -F -d 'Save daemon PID to file'
complete -c create_ap -l logfile -F -d 'Save daemon messages to file'
complete -c create_ap -l stop -x -d 'Send stop command to an already running create_ap'
complete -c create_ap -l list-running -d 'Show already running create_ap processes'
complete -c create_ap -l list-clients -x -d 'List clients connected to create_ap instance with given pid'
complete -c create_ap -l mkconfig -F -d 'Store configs in file'
complete -c create_ap -l config -F -d 'Load configs from file'
complete -c create_ap -l no-dns -d 'Disable dnsmasq DNS server'
complete -c create_ap -l no-dnsmasq -d 'Disable dnsmasq server completely'
complete -c create_ap -s g -x -d 'IPv4 Gateway for the Access Point'
complete -c create_ap -s d -d 'DNS server will consider /etc/hosts'
complete -c create_ap -s e -F -d 'DNS server will consider additional hosts file'
