complete -c stream -o authenticate -d 'Decipher image with this password [password]'
complete -c stream -o channel -d 'Apply option to select image channels [type]' -xa '(stream -list channel)'
complete -c stream -o colorspace -d 'Alternate image colorspace [type]' -xa '(stream -list colorspace)'
complete -c stream -o compress -d 'Type of pixel compression when writing the image [type]' -xa '(stream -list compress)'
complete -c stream -o define -d 'Define one or more image format options [format:option]'
complete -c stream -o density -d 'Horizontal and vertical density of the image [geometry]'
complete -c stream -o depth -d 'Image depth [value]'
complete -c stream -o extract -d 'Extract area from image [geometry]'
complete -c stream -o identify -d 'Identify the format and characteristics of the image'
complete -c stream -o interlace -d 'Type of image interlacing scheme [type]' -xa '(stream -list interlace)'
complete -c stream -o interpolate -d 'Pixel color interpolation method [method]' -xa '(stream -list interpolate)'
complete -c stream -o limit -d 'Pixel cache resource limit [type value]' -x
complete -c stream -o map -d 'Components one or more pixel components'
complete -c stream -o monitor -d 'Monitor progress'
complete -c stream -o quantize -d 'Reduce colors in this colorspace [colorspace]' -xa '(stream -list colorspace)'
complete -c stream -o quiet -d 'Suppress all warning messages'
complete -c stream -o regard-warnings -d 'Pay attention to warning messages'
complete -c stream -o respect-parentheses -d 'Settings remain in effect until parenthesis boundary'
complete -c stream -o sampling-factor -d 'Horizontal and vertical sampling factor [geometry]'
complete -c stream -o seed -d 'Seed a new sequence of pseudo-random numbers [value]'
complete -c stream -o set -d 'Attribute set an image attribute [value]'
complete -c stream -o size -d 'Width and height of image [geometry]'
complete -c stream -o storage-type -d 'Pixel storage type [type]' -xa '(stream -list storage)'
complete -c stream -o synchronize -d 'Synchronize image to storage device'
complete -c stream -o taint -d 'Declare the image as modified'
complete -c stream -o transparent-color -d 'Transparent color [color]' -xa '(__fish_complete_convert_options color)'
complete -c stream -o verbose -d 'Print detailed information about the image'
complete -c stream -o virtual-pixel -d 'Virtual pixel access method [method]' -xa '(stream -list virtual-pixel)'
complete -c stream -o debug -d 'Display copious debugging information [events]' -xa '(stream -list debug)'
complete -c stream -o help -d 'Print program options'
complete -c stream -o list -d 'Print a list of supported option arguments [type]' -xa '(stream -list list)'
complete -c stream -o log -d 'Format of debugging information [format]' -xa '(__fish_complete_convert_options format)'
complete -c stream -o version -d 'Print version information'
