# This file was generated from a corresponding .in file. DO NOT MANUALLY EDIT THIS FILE!
# This function is generated by the autotools build to "compile in"
# the local "vendor" completions, functions and configuration conf.
# It is sourced by share/config.fish, if it exists.

set __extra_completionsdir /usr/share/fish/vendor_completions.d
set __extra_functionsdir /usr/share/fish/vendor_functions.d
set __extra_confdir /usr/share/fish/vendor_conf.d
