if [ ! -f /etc/shells ] || ! grep -q "^/bin/fish$" /etc/shells
then
    echo -e "/bin/fish\n/usr/bin/fish" >> /etc/shells
fi

if [ ! -e /etc/fish/conf.d/00_PATH.fish ]
then
    /usr/bin/mkdir -p /etc/fish/conf.d
    /usr/bin/cp /etc/defaults/etc/fish/conf.d/00_PATH.fish /etc/fish/conf.d/00_PATH.fish
fi

if [ ! -e /etc/fish/conf.d/01_fish_variables.fish ]
then
    /usr/bin/mkdir -p /etc/fish/conf.d
    /usr/bin/cp /etc/defaults/etc/fish/conf.d/01_fish_variables.fish /etc/fish/conf.d/01_fish_variables.fish
fi

if [ ! -e /etc/fish/conf.d/cygwin.fish ]
then
    /usr/bin/mkdir -p /etc/fish/conf.d
    /usr/bin/cp /etc/defaults/etc/fish/conf.d/cygwin.fish /etc/fish/conf.d/cygwin.fish
fi

if [ ! -e /etc/fish/config.fish ]
then
    /usr/bin/mkdir -p /etc/fish
    /usr/bin/cp /etc/defaults/etc/fish/config.fish /etc/fish/config.fish
fi

