complete -c ncdu -s h -l help -d 'Print help'
complete -c ncdu -s q -l slow-ui-updates -d 'Quiet mode. Refresh interval 2 seconds'
complete -c ncdu -l fast-ui-updates -d 'Refresh interval 10 per second'
complete -c ncdu -s v -s V -l version -d 'Print version'
complete -c ncdu -s x -l one-file-system -d 'Same filesystem'
complete -c ncdu -l cross-file-system -d 'Cross filesystems'
complete -c ncdu -s e -l extended -d 'Enable extended information'
complete -c ncdu -l no-extended -d 'Disable extended information'
complete -c ncdu -s r -d 'Read only mode'
complete -c ncdu -s o -d 'Export scanned directory' -r
complete -c ncdu -s f -d 'Import scanned directory' -r
complete -c ncdu -s 0 -s 1 -s 2 -d 'UI to use when scanning (0=none,2=full ncurses)'
complete -c ncdu -l si -d 'Use base 10 prefixes'
complete -c ncdu -l no-si -d 'Use base 2 prefixes'
complete -c ncdu -l exclude -d 'Exclude files that match pattern' -x
complete -c ncdu -s X -l exclude-from -d 'Exclude files that match any pattern in file' -r
complete -c ncdu -s L -l follow-symlinks -d 'Follow symlinks (excluding dirs)'
complete -c ncdu -l no-follow-symlinks -d 'Do not follow symlinks (excluding dirs)'
complete -c ncdu -l exclude-caches -d 'Exclude dirs containing CACHEDIR.TAG'
complete -c ncdu -l include-caches -d 'Include dirs containing CACHEDIR.TAG'
complete -c ncdu -l confirm-quit -d 'Prompt before exiting ncdu'
complete -c ncdu -l no-confirm-quit -d 'No confirmation before exiting ncdu'
complete -c ncdu -l color -d 'Set color scheme' -a 'off dark dark-bg' -x
complete -c ncdu -l ignore-config -d 'Do not load any configuration files'
complete -c ncdu -l include-kernfs -d 'Include Linux pseudo filesystems'
complete -c ncdu -l exclude-kernfs -d 'Exclude Linux pseudo filesystems'
complete -c ncdu -l enable-shell -d 'Enable shell spawning'
complete -c ncdu -l disable-shell -d 'Disable shell spawning'
complete -c ncdu -l enable-delete -d 'Enable built-in file deletion'
complete -c ncdu -l disable-delete -d 'Disable built-in file deletion'
complete -c ncdu -l enable-refresh -d 'Enable directory refreshing'
complete -c ncdu -l disable-refresh -d 'Disable directory refreshing'
complete -c ncdu -l disk-usage -d 'Show disk usage of files'
complete -c ncdu -l apparent-size -d 'Show apparent size of files'
complete -c ncdu -l show-hidden -d 'Show hidden and excluded files'
complete -c ncdu -l hide-hidden -d 'Hide hidden and excluded files'
complete -c ncdu -l show-itemcount -d 'Show the item counts column'
complete -c ncdu -l hide-itemcount -d 'Hide the item counts column'
complete -c ncdu -l show-mtime -d 'Show last modification time column'
complete -c ncdu -l hide-mtime -d 'Hide last modification time column'
complete -c ncdu -l show-graph -d 'Show the relative size bar column'
complete -c ncdu -l hide-graph -d 'Hide the relative size bar column'
complete -c ncdu -l show-percent -d 'Show the relative size percent column'
complete -c ncdu -l hide-percent -d 'Hide the relative size percent column'
complete -c ncdu -l graph-style -d 'Relative size bar column style' -a 'hash half-block eighth-block' -x
complete -c ncdu -l shared-column -d 'Show/hide hard link shared sizes' -a 'off shared unique' -x
complete -c ncdu -l sort -d 'Column to sort on' -a 'disk-usage disk-usage-desc name name-desc apparent-size apparent-size-desc itemcount itemcount-desc mtime mtime-desc' -x
complete -c ncdu -l enable-natsort -d 'Enable natural sort'
complete -c ncdu -l disable-natsort -d 'Disable natural sort'
complete -c ncdu -l group-directories-first -d 'Sort directories before files'
complete -c ncdu -l no-group-directories-first -d 'Do not sort directories before files'
complete -c ncdu -l confirm-delete -d 'Require a confirmation before deleting'
complete -c ncdu -l no-confirm-delete -d 'Do not require a confirmation before deleting'
