complete -c zabbix_web_service -s c -l config -d "Use an alternate config-file."
complete -c zabbix_web_service -s h -l help -d "Display this help and exit."
complete -c zabbix_web_service -s V -l version -d "Output version information and exit."
