# General
complete -c zabbix_js -s s -l script -d "Specify the file name of the script to execute."
complete -c zabbix_js -f -s p -l param -d "Specify the input parameter."
complete -c zabbix_js -s i -l input -d "Specify the file name of the input parameter."
complete -c zabbix_js -f -s l -l loglevel -d "Specify the log level."
complete -c zabbix_js -f -s t -l timeout -d "Specify the timeout in seconds."
complete -c zabbix_js -f -s h -l help -d "Display this help and exit."
complete -c zabbix_js -f -s V -l version -d "Output version information and exit."

