# Completions for Docutils common options
__fish_complete_docutils rstpep2html

# Completions for Docutils HTML options
__fish_complete_docutils_html rstpep2html

# Completions for Docutils PEP/HTML options
complete -c rstpep2html -l python-home -d "Python's home URL"
complete -c rstpep2html -l pep-home -d "Home URL prefix for PEPs"
