complete -c montage -o adjoin -d 'Join images into a single multi-image file'
complete -c montage -o affine -d 'Affine transform matrix [matrix]'
complete -c montage -o alpha -d 'Control alpha/matte channel of an image [option]' -xa '(montage -list alpha)'
complete -c montage -o authenticate -d 'Decipher image with this password [password]'
complete -c montage -o blue-primary -d 'Chromaticity blue primary point [point]'
complete -c montage -o bordercolor -d 'Border color [color]' -xa '(__fish_complete_convert_options color)'
complete -c montage -o caption -d 'Assign a caption to an image [string]'
complete -c montage -o channel -d 'Apply option to select image channels [type]' -xa '(montage -list channel)'
complete -c montage -o colors -d 'Preferred number of colors in the image [value]'
complete -c montage -o colorspace -d 'Alternate image colorsapce [type]' -xa '(montage -list colorspace)'
complete -c montage -o comment -d 'Annotate image with comment [string]'
complete -c montage -o compose -d 'Composite operator [operator]'
complete -c montage -o compress -d 'Type of pixel compression when writing the image [type]' -xa '(montage -list compress)'
complete -c montage -o define -d 'Define one or more image format options [format:option]'
complete -c montage -o density -d 'Horizontal and vertical density of the image [geometry]'
complete -c montage -o depth -d 'Image depth [value]'
complete -c montage -o display -d 'Query font from this X server [server]'
complete -c montage -o dispose -d 'Layer disposal method [method]' -xa '(montage -list dispose)'
complete -c montage -o dither -d 'Apply error diffusion to image [method]' -xa '(montage -list dither)'
complete -c montage -o draw -d 'Annotate the image with a graphic primitive [string]'
complete -c montage -o encoding -d 'Encoding type [type text]' -xa '(__fish_print_encodings)'
complete -c montage -o endian -d 'Endianness (MSB or LSB) of the image [type]' -xa '(montage -list endian)'
complete -c montage -o extract -d 'Extract area from image [geometry]'
complete -c montage -o fill -d 'Color to use when filling a graphic primitive [color]' -xa '(__fish_complete_convert_options color)'
complete -c montage -o filter -d 'Use this filter when resizing an image [type]' -xa '(montage -list filter)'
complete -c montage -o font -d 'Render text with this font [name]' -xa '(__fish_complete_convert_options font)'
complete -c montage -o format -d 'Output formatted image characteristics ["string"]'
complete -c montage -o gamma -d 'Level of gamma correction [value]'
complete -c montage -o geometry -d 'Preferred tile and border sizes [geometry]'
complete -c montage -o gravity -d 'Direction which direction to gravitate towards'
complete -c montage -o green-primary -d 'Chromaticity green primary point [point]'
complete -c montage -o identify -d 'Identify the format and characteristics of the image'
complete -c montage -o interlace -d 'Type of image interlacing scheme [type]' -xa '(montage -list interlace)'
complete -c montage -o interpolate -d 'Pixel color interpolation method [method]' -xa '(montage -list interpolate)'
complete -c montage -o kerning -d 'Set the space between two letters [value]'
complete -c montage -o label -d 'Assign a label to an image [string]'
complete -c montage -o limit -d 'Pixel cache resource limit [type value]' -x
complete -c montage -o mattecolor -d 'Frame color [color]' -xa '(__fish_complete_convert_options color)'
complete -c montage -o mode -d 'Framing style [type]' -xa '(montage -list mode)'
complete -c montage -o monitor -d 'Monitor progress'
complete -c montage -o origin -d 'Image origin [geometry]'
complete -c montage -o page -d 'Size and location of an image canvas (setting) [geometry]'
complete -c montage -o pointsize -d 'Font point size [value]'
complete -c montage -o profile -d 'Add, delete, or apply an image profile [filename]' -r
complete -c montage -o quality -d 'JPEG/MIFF/PNG compression level [value]'
complete -c montage -o quantize -d 'Reduce colors in this colorspace [colorspace]' -xa '(montage -list colorspace)'
complete -c montage -o quiet -d 'Suppress all warning messages'
complete -c montage -o red-primary -d 'Chromaticity red primary point [point]'
complete -c montage -o regard-warnings -d 'Pay attention to warning messages'
complete -c montage -o respect-parentheses -d 'Settings remain in effect until parenthesis boundary'
complete -c montage -o sampling-factor -d 'Horizontal and vertical sampling factor [geometry]'
complete -c montage -o scenes -d 'Range image scene range'
complete -c montage -o seed -d 'Seed a new sequence of pseudo-random numbers [value]'
complete -c montage -o set -d 'Attribute set an image attribute [value]'
complete -c montage -o shadow -d 'Add a shadow beneath a tile to simulate depth'
complete -c montage -o size -d 'Width and height of image [geometry]'
complete -c montage -o stroke -d 'Color to use when stroking a graphic primitive [color]' -xa '(__fish_complete_convert_options color)'
complete -c montage -o synchronize -d 'Synchronize image to storage device'
complete -c montage -o taint -d 'Declare the image as modified'
complete -c montage -o texture -d 'Texture name to tile onto the image background [filename]' -r
complete -c montage -o thumbnail -d 'Create a thumbnail of the image [geometry]'
complete -c montage -o tile -d 'Number of tiles per row and column [geometry]'
complete -c montage -o title -d 'Decorate the montage image with a title [string]'
complete -c montage -o transparent-color -d 'Transparent color [color]' -xa '(__fish_complete_convert_options color)'
complete -c montage -o treedepth -d 'Color tree depth [value]'
complete -c montage -o trim -d 'Trim image edges'
complete -c montage -o units -d 'The units of image resolution [type]' -xa '(montage -list units)'
complete -c montage -o verbose -d 'Print detailed information about the image'
complete -c montage -o virtual-pixel -d 'Virtual pixel access method [method]' -xa '(montage -list virtual-pixel)'
complete -c montage -o white-point -d 'Chromaticity white point [point]'
complete -c montage -o adaptive-sharpen -d 'Adaptively sharpen pixels; increase effect near edges [geometry]'
complete -c montage -o auto-orient -d 'Automagically orient (rotate) image'
complete -c montage -o blur -d 'Reduce image noise and reduce detail levels [geometry]'
complete -c montage -o border -d 'Surround image with a border of color [geometry]'
complete -c montage -o crop -d 'Preferred size and location of the cropped image [geometry]'
complete -c montage -o extent -d 'Set the image size [geometry]'
complete -c montage -o flatten -d 'Flatten a sequence of images'
complete -c montage -o flip -d 'Flip image in the vertical direction'
complete -c montage -o flop -d 'Flop image in the horizontal direction'
complete -c montage -o frame -d 'Surround image with an ornamental border [geometry]'
complete -c montage -o monochrome -d 'Transform image to black and white'
complete -c montage -o polaroid -d 'Simulate a Polaroid picture [angle]'
complete -c montage -o repage -d 'Size and location of an image canvas (operator) [geometry]'
complete -c montage -o resize -d 'Resize the image [geometry]'
complete -c montage -o rotate -d 'Apply Paeth rotation to the image [degrees]'
complete -c montage -o strip -d 'Strip image of all profiles and comments'
complete -c montage -o transform -d 'Affine transform image'
complete -c montage -o transpose -d 'Flip image vertically and rotate 90 degrees'
complete -c montage -o transparent -d 'Make this color transparent within the image [color]' -xa '(__fish_complete_convert_options color)'
complete -c montage -o type -d 'Image type [type]' -xa '(montage -list type)'
complete -c montage -o unsharp -d 'Sharpen the image [geometry]'
complete -c montage -o coalesce -d 'Merge a sequence of images'
complete -c montage -o composite -d 'Composite image'
complete -c montage -o clone -d 'Clone an image [indexes]'
complete -c montage -o delete -d 'Delete the image from the image sequence [indexes]'
complete -c montage -o duplicate -d 'Duplicate an image one or more times [count,indexes]'
complete -c montage -o insert -d 'Insert last image into the image sequence [index]'
complete -c montage -o reverse -d 'Reverse image sequence'
complete -c montage -o swap -d 'Swap two images in the image sequence [indexes]'
complete -c montage -o debug -d 'Display copious debugging information [events]' -xa '(montage -list debug)'
complete -c montage -o help -d 'Print program options'
complete -c montage -o list -d 'Print a list of supported option arguments [type]' -xa '(montage -list list)'
complete -c montage -o log -d 'Format of debugging information [format]' -xa '(__fish_complete_convert_options format)'
complete -c montage -o version -d 'Print version information'
complete -c montage -o matte -d 'Store matte channel if the image has one'
complete -c montage -o support -d 'Resize support: > 1.0 is blurry, < 1.0 is sharp [factor]'
complete -c montage -o annotate -d 'Annotate the image with text [geometry text]'
