complete -c xviewer -s h -l help -d 'Show help and exit'
complete -c xviewer -l version -d 'Show version and exit'

complete -c xviewer -l usage -d 'Show help and exit'
complete -c xviewer -l disable-sound -d 'Do not use sound server'
complete -c xviewer -l enable-sound -d 'Use sound server'
complete -c xviewer -l espeaker -d 'Host:port on which sound'
complete -c xviewer -l gdk-debug -d 'Enabled Gdk flags'
complete -c xviewer -l gdk-no-debug -d 'Disabled Gdk flags'
complete -c xviewer -l display -d 'X display'
complete -c xviewer -l sync -d 'Synchronize X calls'
complete -c xviewer -l no-xshm -d 'Do not use X shared memory extension'
complete -c xviewer -l name -d 'Program name'
complete -c xviewer -l class -d 'Program class'
complete -c xviewer -l gxid_host
complete -c xviewer -l gxid_port
complete -c xviewer -l xim-preedit
complete -c xviewer -l xim-status
complete -c xviewer -l gtk-debug -d 'Enabled Gtk+ flags'
complete -c xviewer -l gtk-no-debug -d 'Disabled Gtk+ flags'
complete -c xviewer -l g-fatal -d 'Treat warnings as fatal errors'
complete -c xviewer -l gtk-module -d 'Additinal Gtk module'
complete -c xviewer -l disable-crash-dialog
complete -c xviewer -l sm-client-id -d 'Session management ID'
complete -c xviewer -l sm-config-prefix -d 'Prefix of saved configuration'
complete -c xviewer -l sm-disable -d 'Disable connection to session manager'
